@@ -59,6 +59,7 @@ extern int save_fasta_file(const char *fname, char **seq, char **comments, char
 extern void direct_help_callback(Fl_Widget *wgt, void *data);
 extern int compute_size_params(SEA_VIEW *view, int force_recompute);
 extern char **prepcolranks_by_codon(char **seq, int totseqs, int maxlen, int *eachlength, char **comments);
+extern int is_view_valid(SEA_VIEW *view);
 #ifdef WIN32
 extern "C" { int mysystem(const char *command); }
 #endif
@@ -85,15 +86,14 @@ maxlen = 0; current = 0;
 for(num = 0; num < tot_seqs; num++) {
 	if(! sel_seqs[num] ) continue;
 	empty_seq = TRUE;
-	sprintf(line, "%d_%.10s", ++current, seqname[num]);
-	sprintf(lname, ">%.10s\n", line);
 	l_line = 0;
 	seqlen = 0;
 	for ( pos = debut - 1 ; pos < fin; pos++) {
 		if( sequence[num][pos] == 0 ) break;
 		if( sequence[num][pos] == '-' ) continue;
 		if(empty_seq) {
-			fputs(lname, out);
+			sprintf(lname, "%d_%.10s", ++current, seqname[num]);
+			fprintf(out, ">%.10s\n", lname);
  			if(ferror(out)) goto fin;
 			empty_seq = FALSE;
 			}
@@ -222,14 +222,16 @@ if( status == 0 ) {
 		}
 	else	status = 1;
 	}
-if( status != 0 )
-	fl_message("%s: alignment operation ignored", extract_filename(view->masename));
-else	{
-	status = replace_align_part(view, debut, fin, fname, withU, num_longest, tmpselseqs, my_align_choice );
-	if(status) fl_alert("Not enough memory\nor\n" 
-		"max sequence length reached");
-	else if(my_align_choice == ALIGN_ALL) del_gap_only_sites(view);
-	}
+if (is_view_valid(view)) {
+  if( status != 0 )
+	  fl_message("%s: alignment operation ignored", extract_filename(view->masename));
+  else	{
+	  status = replace_align_part(view, debut, fin, fname, withU, num_longest, tmpselseqs, my_align_choice );
+	  if(status) fl_alert("Not enough memory\nor\n" 
+		  "max sequence length reached");
+	  else if(my_align_choice == ALIGN_ALL) del_gap_only_sites(view);
+	  }
+}
 free(tmpselseqs);
 sprintf(fname, "%s.pir", base_fname);
 remove(fname);
@@ -563,11 +565,6 @@ if(status) {
 	
 sprintf(tmp, "msa_args_%d", view->alignment_algorithm +  1);
 strcpy(local, get_res_value(tmp, NULL));
-  
-  if(view->alignment_algorithm == 1 && (p = strstr(local, " -stable")) != NULL) {
-    //make sure -stable is not in muscle arguments because it's buggy
-    memmove(p, p+8, strlen(p+8)+1);
-    }
 
 /* add user-entered options to command */
 Fl_Menu_Button *menu_align = (Fl_Menu_Button *)view->menu_align;
@@ -584,6 +581,12 @@ if(optargs != NULL && (status & FL_MENU_VALUE) ) {
 		}
 	strcpy(local, tmp);
 	}
+  
+  if(view->alignment_algorithm == 1 && (p = strstr(local, " -stable")) != NULL) {
+    //make sure -stable is not in muscle arguments because it's buggy
+    memmove(p, p+8, strlen(p+8)+1);
+  }
+  
 /* replace all %f by file names */
 while((p = strstr(local, "%f")) != NULL) {
 	*p = 0;
@@ -612,17 +615,21 @@ void align_menu_callback(Fl_Widget *ob, void *unused)
 	SEA_VIEW *view = (SEA_VIEW *) ob->user_data();
 	Fl::remove_timeout(fix_paste_timeout);
 	if(reponse <= ALIGN_SITES) { 
-		align_selected_parts(view, view->alignment_algorithm, reponse );
-		view->DNA_obj->redraw();
-		view->horsli->redraw();
-		fl_reset_cursor(view->dnawin);
+	  align_selected_parts(view, view->alignment_algorithm, reponse );
+	  if(is_view_valid(view)) {
+	    view->DNA_obj->redraw();
+	    view->horsli->redraw();
+	    fl_reset_cursor(view->dnawin);
+	    }
 	}
 	else if(reponse == PROFILE) {
-		if(view->tot_sel_seqs == 0) return;
-		profile_align(view);
-		view->DNA_obj->redraw();
-		view->horsli->redraw();
-		fl_reset_cursor(view->dnawin);
+	  if(view->tot_sel_seqs == 0) return;
+	  profile_align(view);
+	  if(is_view_valid(view)) {
+	    view->DNA_obj->redraw();
+	    view->horsli->redraw();
+	    fl_reset_cursor(view->dnawin);
+	    }
 	}
 	else if(reponse == UNALIGN) {
 		if(view->tot_sel_seqs == 0) return;
@@ -1124,6 +1131,7 @@ void profile_align(SEA_VIEW *view)
 		}
 	}
 	remove(fname1);
+	if ( !is_view_valid(view) ) return;
 	if( status != 0 || num != total) {
 		fl_message("%s: alignment operation ignored", extract_filename(view->masename));
 		return; 
@@ -1150,14 +1158,27 @@ void profile_align(SEA_VIEW *view)
     p = view->sequence[num_align]; // one profile seq
     q = seq[0]; // this seq after profile alignment
     while(*p != 0) {
-      while(*p != 0 && *p == *q) {
+      while(*p != 0 && toupper(*p) == toupper(*q)) {
 	p++; q++;
 	}
       if(*p == 0 && *q == 0) break;
-      if(*q == '-') {
+      if(*p == '-') {
+	int from = q - seq[0];
+	l = 1;
+	p++;
+	while(toupper(*p) != toupper(*q)) { p++; l++; }
+	for(num = 0; num < total; num++) {
+	  seq[num] = (char*)realloc(seq[num], strlen(seq[num]) + l + 1);
+	  memmove(seq[num] + from + l, seq[num] + from, strlen(seq[num] + from) + 1);
+	  memset(seq[num] + from, '-', l);
+	  }
+	q = seq[0] + from + l;
+	l = 0;
+      }
+      else if(*q == '-') {
 	l = 1;
 	q++;
-	while(*q != *p) { q++; l++; }
+	while(toupper(*p) != toupper(*q)) { q++; l++; }
 	}
       if(l > 0) {
 	//insert gap of length l in regions
