@@ -1,7 +1,6 @@
 #ifdef __APPLE__
-#include <Carbon/Carbon.h>
 #import <Cocoa/Cocoa.h>
-#if ! (defined(__LP64__) && __LP64__)
+#ifdef __ppc__
 #include <QuickTime/QuickTimeComponents.h>
 #endif
 #ifndef NSINTEGER_DEFINED //appears with 10.5 in NSObjCRuntime.h
@@ -19,7 +18,6 @@ typedef unsigned int NSUInteger;
 #include <FL/Fl_Help_View.H>
 #include <FL/filename.H>
 #include "FL/fl_draw.H"
-#include "src/Fl_Font.H"
 #include <sys/stat.h>
 #include <unistd.h>
 
@@ -342,11 +340,9 @@ void show_apropos(Fl_Widget *w, void *unused)
 
 void MG_apple_inits(void)
 {
-  SInt32 MACsystemVersion;
   Fl::set_font(FL_COURIER,"Courier");
   Fl::set_font(FL_COURIER_BOLD,"Courier Bold");
-  Gestalt(gestaltSystemVersion, &MACsystemVersion);
-  if (MACsystemVersion >= 0x1050) { // it seems that Courier Oblique is not present on older OS
+  if (fl_mac_os_version >= 100500) { // it seems that Courier Oblique is not present on older OS
     Fl::set_font(FL_COURIER_ITALIC,"Courier Oblique");
     Fl::set_font(FL_COURIER_BOLD_ITALIC,"Courier Bold Oblique");
     }
@@ -642,7 +638,7 @@ void complete_copy_pdf_and_pict(void *data)
   
   //second, transform this PDF to a bitmap image and put it as PICT/jpeg in clipboard
   CGDataProviderRef prov;
-  if(CGDataProviderCreateWithCFData != NULL) { // true from 10.4
+  if(fl_mac_os_version >= 100400) { // true from 10.4
     prov = CGDataProviderCreateWithCFData(pdfdata);
     }
   else {
@@ -655,11 +651,7 @@ void complete_copy_pdf_and_pict(void *data)
   h = (int)(clip.size.height + 0.5);
   CGDataProviderRelease(prov);
   CGColorSpaceRef space = CGColorSpaceCreateWithName(
-#if MAC_OS_X_VERSION_MAX_ALLOWED >= MAC_OS_X_VERSION_10_4
-						     kCGColorSpaceGenericRGB
-#else
-						     kCGColorSpaceUserRGB
-#endif
+				fl_mac_os_version >= 100400 ? kCGColorSpaceGenericRGB : kCGColorSpaceUserRGB	     
 						     );
   const int scale = 2;
   w *= scale; h *= scale;
@@ -673,7 +665,7 @@ void complete_copy_pdf_and_pict(void *data)
   CGContextDrawPDFDocument(fl_gc, rect, pdfdoc, 1);
   CGPDFDocumentRelease(pdfdoc);
   CFRelease(pdfdata);
-  if(CGBitmapContextCreateImage != NULL) {// way for >= 10.4 that doesn't use QuickTime:
+  if(fl_mac_os_version >= 100400) {// way for >= 10.4 that doesn't use QuickTime:
     CFMutableDataRef pictdata = CFDataCreateMutable(NULL, 0);
 #if __LP64__
     CFStringRef  uti = CFSTR("public.tiff");
@@ -694,7 +686,7 @@ void complete_copy_pdf_and_pict(void *data)
     CFRelease (pictdata);    
     }
   else {// way for < 10.4 that uses QuickTime:
-#if !__LP64__
+#ifdef __ppc__
     GraphicsExportComponent exporter;
     OSErr err = OpenADefaultComponent(GraphicsExporterComponentType, kQTFileTypePicture /*'PICT'*/, &exporter);
     err = GraphicsExportSetInputCGBitmapContext(exporter, fl_gc);
