@@ -318,7 +318,7 @@ extern char **prepcolranks(char **seq, int totseqs, int maxlen, int *eachlength,
 	int (*calc_color_function)( int ), int numb_gc, int allow_lower);
 extern char complement_base(char old);
 extern void select_deselect_seq(SEA_VIEW *view, int new_seq);
-extern void save_active_region(SEA_VIEW *view, int ask_confirm);
+extern void save_active_region(SEA_VIEW *view);
 extern void align_selected_parts(SEA_VIEW *view, int align_algorithm, align_choice my_align_choice);
 extern void free_region(region *reg);
 extern void my_watch_cursor(Fl_Window *win);
