@@ -9,6 +9,19 @@
 
 #define myrint(x) (int)floor(x + 0.5)
 
+#if !(defined(__APPLE__) || defined(WIN32)) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  + FL_PATCH_VERSION == 130
+// for X11 under 1.3.0 only
+#include <FL/Fl_Printer.H>
+class corr_Fl_Printer : public Fl_Printer {
+  int count, m, M;
+public:
+  corr_Fl_Printer();
+  int start_job(int pagecount, int *frompage=NULL, int *topage=NULL);
+  int start_page();
+};
+#define Fl_Printer corr_Fl_Printer
+#endif
+
 struct noeud {
 	double l1,l2,l3;
 	struct noeud *v1,*v2,*v3;
