@@ -2,7 +2,7 @@
 #include <time.h>
 #include "unrooted.h"
 #include "treedraw.h"
-#if defined(MICRO)
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 103
 #include <FL/Fl_Printer.H>
 #endif
 
@@ -65,7 +65,7 @@ double length_log_phys(FD_unrooted *data, double p);
 double length_phys_log(FD_unrooted *data, double p);
 void squared2circular(FD_nj_plot *fd_nj_plot, Fl_Choice *o);
 void circular2squared(FD_nj_plot *fd_nj_plot);
-#ifdef MICRO
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 103
 void print_unrooted(FD_unrooted *fd_unrooted);
 #endif
 
@@ -193,7 +193,7 @@ void squared2circular(FD_nj_plot *fd_nj_plot, Fl_Choice *o)
 	edit_item[fd_nj_plot->edit_shape_rank].deactivate();//edit shape
 	item[2].deactivate();//save rooted tree
 	item[3].deactivate();//save unrooted tree
-	item[8].deactivate();//Page count
+	item[9].deactivate();//Page count
 	fd_unrooted->zoomvalue = 1;
 	fd_nj_plot->zoom->value(1);
 	Fl_Window *w2 = (Fl_Window *)panel->parent();
@@ -259,7 +259,7 @@ void circular2squared(FD_nj_plot *fd_nj_plot)
   edit_item[fd_nj_plot->edit_shape_rank].activate();//edit shape
   item[2].activate();
   item[3].activate();
-  item[8].activate();
+  item[9].activate();
 }
 
 void unrooted_scroller_cb(Fl_Widget *wgt, void *data)
@@ -449,7 +449,8 @@ void postscript_unrooted(FD_unrooted *fd_unrooted, const char *name)
 	if(fd_unrooted->notu == 0) return;
 	Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
 	chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
-	chooser->title("Set PDF filename");                        
+	chooser->title("Set PostScript filename");                        
+  chooser->filter("PostScript Files\t*.ps");
 	char tmp[100];
 	strcpy(tmp, extract_filename(name));
 	char *p = strrchr(tmp, '.'); if(p != NULL) *p = 0;
@@ -475,11 +476,13 @@ void postscript_unrooted(FD_unrooted *fd_unrooted, const char *name)
 			"%%%%Creator: seaview\n"
 			"%%%%Pages: 1\n"
 			"%%%%Title: %s\n"
-			"%%%%BeginFeature: *PageSize \n"
-			"%s\n"
+			"%%%%BeginFeature: *PageSize %s\n"
+		"<</PageSize[%d %d]>>setpagedevice\n"
 			"%%%%EndFeature\n"
 			"%%%%EndComments\n",
-			current_ps_font, name, printout_pageformat == A4 ? "a4" : "letter" );
+			current_ps_font, name, printout_pageformat == A4 ? "A4" : "Letter",
+		printout_pageformat == A4 ? a4_w : letter_w, 
+		printout_pageformat == A4 ? a4_h : letter_h);
 	fprintf(plotfile,
 			"/setpacking where {true setpacking} if\n"
 			"1 setlinecap 1 setlinejoin 1 setlinewidth 0 setgray\n");
@@ -501,6 +504,9 @@ void postscript_unrooted(FD_unrooted *fd_unrooted, const char *name)
 	
 	fprintf(plotfile,"%%%%EndProlog\n");
 	fprintf(plotfile,"%%%%Page: 1 1\n");
+  fprintf(plotfile, "%%%%PageBoundingBox: 0 0 %d %d\n", 
+	  printout_pageformat == A4 ? a4_w : letter_w, 
+	  printout_pageformat == A4 ? a4_h : letter_h);
 	fprintf(plotfile,"title ");
 	fprintf(plotfile,"setclip\n");
 	fprintf(plotfile,"%d %d translate\n", margin, margin);
@@ -550,6 +556,7 @@ void pdf_unrooted(FD_unrooted *fd_unrooted, const char *name)
 	if(fd_unrooted->notu == 0) return;
 	Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
 	chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
+  chooser->filter("PDF Files\t*.pdf");
 	chooser->title("Set PDF filename");                        
 	char tmp[100];
 	strcpy(tmp, extract_filename(name));
@@ -633,19 +640,19 @@ void pdf_unrooted(FD_unrooted *fd_unrooted, const char *name)
 }
 #endif
 
-#if defined(MICRO)
+#if 100*FL_MAJOR_VERSION + FL_MINOR_VERSION >= 103
 void print_unrooted(FD_unrooted *fd_unrooted, const char *name)
 {
   int from, to;
   Fl_Printer myprinter;
   if(myprinter.start_job(1, &from, &to) ) return;
+  myprinter.start_page();
   fd_unrooted->previous_w = fd_unrooted->previous_h = 0;
   myprinter.printable_rect( &fd_unrooted->w, &fd_unrooted->h);
   fd_unrooted->x = fd_unrooted->y = 0;
   int old_x = fd_unrooted->x_offset;
   int old_y = fd_unrooted->y_offset;
   fd_unrooted->x_offset = fd_unrooted->y_offset = 0;
-  myprinter.start_page();
   fd_unrooted->y += 20;
   fd_unrooted->h -= 20;
   time_t heure;
