@@ -62,7 +62,7 @@ static void save_species_sets(int numb_species_sets, int **list_species_sets,
 void save_comment_lines(int tot_comment_lines, char **names, char **lines, 
 	FILE *out);
 known_format what_format(const char *filename);
-char* seaview_file_chooser_save_as(const char* message, const char* fname, SEA_VIEW *view);
+char* seaview_file_chooser_save_as(const char* message, const char* fname, SEA_VIEW *view, known_format* new_format);
 const char *extract_dirname(const char *pathname);
 
 
@@ -80,7 +80,6 @@ extern int save_nexus_file(const char *fname, int ntaxa, int protein,
 	int tot_comment_lines, char **comment_name, char **comment_line,
 	region *region_used, int *sel_seqs, int tot_sel_seqs, int *eachlength,
 	int tot_trees, char **trees, const Fl_Menu_Item *items);
-extern void set_save_format(SEA_VIEW *view, int val);
 extern "C" {
 	char *my_fgets(char *s, int n, FILE *f);
 }
@@ -1750,7 +1749,7 @@ return (p == s ? NULL : s);
 }
 
 
-char *seaview_file_chooser_save_as(const char* message, const char* fname, SEA_VIEW *view)
+char *seaview_file_chooser_save_as(const char* message, const char* fname, SEA_VIEW *view, known_format* new_format)
 {
 #ifndef MICRO
   const char *prev_label = Fl_File_Chooser::show_label;
@@ -1775,7 +1774,7 @@ for(int f = 0; f < nbr_formats; f++) {
 chooser->filter(types_list);    
 chooser->filter_value(view->format_for_save);    
 char *filename = run_and_close_native_file_chooser(chooser, TRUE);
-if(filename != NULL) set_save_format((SEA_VIEW *)view, chooser->filter_value());
+if (filename && new_format) *new_format = (known_format)chooser->filter_value();
 delete chooser;
 return filename;
 }
