@@ -33,7 +33,7 @@ oldtotsel = view->tot_sel_seqs;
 oldselseqs = view->sel_seqs;
 oldcursorseq = view->cursor_seq;
 oldcursorsite = view->cursor_site;
-save_active_region(view, FALSE);
+save_active_region(view);
 masename = view->masename;
 get_menu_taille_valeur( (Fl_Menu_ *)(view->menu_regions), &taille, &oldsites);
 if(onoff) { /* ON */
@@ -67,7 +67,7 @@ if(onoff) { /* ON */
 	      lseg = lseg->next;
 	      }
 	    if(lreg->element->hide_when_viewasprots) { // inactivate in menu if hide_when_viewasprots is on
-	      ((Fl_Menu_Button*)view->menu_regions)->mode(5 + i - 1, FL_MENU_RADIO | FL_MENU_INACTIVE);
+	      ((Fl_Menu_Button*)view->menu_regions)->mode(4 + i - 1, FL_MENU_RADIO | FL_MENU_INACTIVE);
 	      if(i == oldsites) oldsites = 0; // and don't show it as active region
 	    }
 	    lreg = lreg->next;
@@ -130,7 +130,7 @@ free(view->sel_seqs);
 free(masename);
 view->sel_seqs = oldselseqs;
 if(oldsites) {
-  ((Fl_Menu_ *)(view->menu_regions))->value(oldsites + 4);
+  ((Fl_Menu_ *)(view->menu_regions))->value(oldsites + 3);
   ((Fl_Menu_ *)(view->menu_regions))->do_callback();
   }
 select_deselect_seq(view, -2);
@@ -244,21 +244,21 @@ void set_ncbi_genetic_code(SEA_VIEW *view)
 int gc = 1, num;
 char line[170];
 int status;
-static char codencbinames[17][60] = { "Standard", "Yeast mt", "Vertebrate mt",
+static char codencbinames[18][60] = { "Standard", "Yeast mt", "Vertebrate mt",
 	"Mold+Protozoan+Coelentarate mt, Mycoplasma Spiroplasma", "Invertebrate mt", "Alternative Yeast Nuclear", 
 	"Ciliate+Dasycladacean+Hexamita Nuclear", "Euplotid Nuclear", "Echinoderm+Flatworm mt",
 	"Ascidian mt", "Alternative Flatworm mt", "Blepharisma Macronuclear", 
 	"Bacterial and Plant Plastid", "Chlorophycean mt", "Trematode mt", 
-	"Scenedesmus obliquus mt", "Thraustochytrium mt"};
+	"Scenedesmus obliquus mt", "Thraustochytrium mt", "Pterobranchia mt"};
 
 if(view->comments == NULL) view->comments = (char **)calloc(view->tot_seqs, sizeof(char *));
 if(view->comments == NULL) return;
-Fl_Window *win = new Fl_Window(750,330);
+Fl_Window *win = new Fl_Window(750,360);
 win->label("Genetic code selection");
 for(num = 0; num < view->tot_seqs; num++)
 		if(view->sel_seqs[num]) break;
 gc = get_ncbi_gc_from_comment(view->comments[num]);
-Fl_Hold_Browser *obj = new Fl_Hold_Browser(5, 25, 740, 280);
+Fl_Hold_Browser *obj = new Fl_Hold_Browser(5, 25, 740, 310);
 obj->textfont(FL_COURIER);
 sprintf(line, "Set genetic code for %s", view->tot_sel_seqs > 1 ? "selected sequences" : view->seqname[num]);
 obj->copy_label(line);
