@@ -5,6 +5,12 @@
 #include <string.h>
 #include <ctype.h>
 
+#ifndef NO_PDF
+#include <pdflib.h>
+extern PDF *pdf;
+#endif
+
+
 #define MAXSEQLENGTH 10000 /* pas utilise pour interface avec seaview */
 #define MAXSEGMENTS 20000
 #define segment_x_ou_y(num, offset) \
@@ -199,7 +205,7 @@ fin += width + 2;
 compute->callback(compute_proc, fdui);
 fdui->compute_butt = compute;
 
-Fl_Widget *postscript = cre_button(fin, curr_y, &width, but_height, fontsize, "Write Postscript");
+Fl_Widget *postscript = cre_button(fin, curr_y, &width, but_height, fontsize, "Write "PDF_OR_PS);
 fin += width;
 postscript->callback(plot_button_proc, fdui);
 
@@ -778,10 +784,19 @@ void ps_draw_line(int x1, int y1, int x2, int y2, FD_matpt *matpt,
 int px, py;
 px = (int)floor(x1 * matpt->factor + matpt->kx + 0.5);
 py = (int)floor(y1 * matpt->factor + matpt->ky + 0.5);
+#ifdef NO_PDF
 fprintf(plotfile,"%d %d moveto ",px,py);
+#else
+  PDF_moveto(pdf, px, py); 
+#endif
 px = (int)floor(x2 * matpt->factor + matpt->kx + 0.5);
 py = (int)floor(y2 * matpt->factor + matpt->ky + 0.5);
+#ifdef NO_PDF
 fprintf(plotfile,"%d %d lineto stroke\n",px,py);
+#else
+  PDF_lineto(pdf, px, py); 
+  PDF_stroke(pdf);
+#endif
 }
 
 void ps_set_mat_data(FD_matpt *matpt)
@@ -802,26 +817,75 @@ void plot_button_proc(Fl_Widget *ob, void *data)
 {
 FD_matpt *matpt = (FD_matpt *)data;
 int i;
-char plotfname[150], *sp;
+char *plotfname, *sp, message[200];
 int old_phys;
 FILE *plotfile;
 
-strcpy(plotfname, matpt->plotname);
-sp = strchr(plotfname,'.'); 
-if( sp == NULL || strcmp(sp, ".ps") == 0 ) 
-	sp = plotfname+strlen(plotfname);
-strcpy(sp, ".ps");
-plotfile=fopen(plotfname,"w");
+  Fl_Native_File_Chooser *chooser = new Fl_Native_File_Chooser();
+  chooser->type(Fl_Native_File_Chooser::BROWSE_SAVE_FILE);
+  chooser->title("Set "PDF_OR_PS" filename");       
+  strcpy(message, matpt->plotname);
+  sp = strchr(message,'.'); 
+  if( sp == NULL ) sp = message + strlen(message);
+  strcpy(sp, "."PDF_OR_PS);
+  chooser->preset_file(message);
+  chooser->filter(
+#ifdef NO_PDF
+		  "PostScript"
+#else
+		  "PDF"
+#endif
+		  "\t*."PDF_OR_PS"\n");    
+  chooser->filter_value(0);    
+  plotfname = run_and_close_native_file_chooser(chooser);
+  if(plotfname == NULL) return;
+#ifdef NO_PDF
+plotfile = fopen(plotfname,"w");
 if(plotfile == NULL) {
-	fl_alert("Cannot write to file\n%s", plotfname);
-	return;
-	}
-fprintf(plotfile,"%%!\n1 setlinecap 1 setlinejoin 1 setlinewidth 0 setgray\n");
+  fl_alert("Cannot write to file\n%s", plotfname);
+  return;
+  }
+fputs("%%!PS-Adobe-3.0\n"
+  "%%Creator: FLTK\n"
+  "%%LanguageLevel: 2\n"
+  "%%Pages: 1\n"
+  "%%BeginFeature: *PageSize A4-Letter\n"
+  "<</PageSize[595 792]>>setpagedevice\n"
+  "%%EndFeature\n"
+  "%%EndComments\n"
+  "%%Page: 1 1\n"
+  "%%PageOrientation: Portrait\n"
+  , plotfile);
+fprintf(plotfile, "1 setlinecap 1 setlinejoin 1 setlinewidth 0 setgray\n");
 fprintf(plotfile,"/basefont /Helvetica findfont 12 scalefont def\n");
 fprintf(plotfile,"basefont setfont\n");
 fprintf(plotfile,"50 200 translate\n");
 fprintf(plotfile,"-10 -10 moveto 510 -10 lineto 510 510 lineto -10 510 lineto \
 -10 -10 lineto stroke\n");
+#else
+  pdf = PDF_new();
+  if(pdf == NULL) return;
+  if( PDF_begin_document(pdf, plotfname, 0, "compatibility=1.3") == -1) {
+    PDF_delete(pdf);
+    fl_alert("Error opening %s for writing.", plotfname);
+    return;
+  }
+PDF_TRY(pdf) {
+  PDF_set_info(pdf, "Title", plotfname );
+  PDF_set_info(pdf, "Creator", "seaview");
+  int font = PDF_load_font(pdf, "Helvetica", 0, "iso8859-1", "");
+  PDF_begin_page_ext(pdf, 595, 792, "");
+  PDF_setfont(pdf, font, 12);
+  PDF_setlinecap(pdf, 1);
+  PDF_setlinewidth(pdf, 1);
+  PDF_translate(pdf, 50, 200);
+  PDF_moveto(pdf, -10, -10);
+  PDF_lineto(pdf, 510, -10);
+  PDF_lineto(pdf, 510, 510);
+  PDF_lineto(pdf, -10, 510);
+  PDF_lineto(pdf, -10, -10);
+  PDF_stroke(pdf);
+#endif
 
 old_phys = matpt->phys_width; matpt->phys_width = 500;
 ps_set_mat_data(matpt);
@@ -837,14 +901,37 @@ for (i = 0; i <= matpt->totsegments; i++)	{
 matpt->phys_width = old_phys;
 reset_mat_data(matpt);
 
-fl_message("Dot plot is now in file\n%s\nin postscript format", plotfname);
-sprintf(plotfname,
+sprintf(message,
 	"Horizontal: %.30s (%d)  Vertical: %.30s (%d)  Window: %d Matches: %d",
 	matpt->seqname1, matpt->seqlong1, matpt->seqname2, matpt->seqlong2, 
 		matpt->fenetre, matpt->identites);
-fprintf(plotfile,"-10 -30 moveto (%s) show\n",plotfname);
-fprintf(plotfile,"showpage\n");
+#ifdef NO_PDF
+fprintf(plotfile,"-10 -30 moveto (%s) show\n", message);
+fputs("showpage\n%%EOF\n", plotfile);
 fclose(plotfile);
+#else
+  PDF_show_xy(pdf, message, -10, -30);
+  PDF_end_page_ext(pdf, "");
+  PDF_end_document(pdf, "");
+  PDF_delete(pdf);
+} /* end of PDF_TRY */
+PDF_CATCH(pdf) {
+  if(pdf_catch(pdf)) {
+    fl_alert("Error while writing pdf file:\n"
+	     "[%d] %s: %s\n",
+	     PDF_get_errnum(pdf), PDF_get_apiname(pdf), PDF_get_errmsg(pdf) );
+    PDF_delete(pdf);
+    return;
+    }
+  }
+#endif
+#ifndef MICRO
+  matpt->form->hide(); Fl::flush(); // because of strange bug on 32-bit Linux only
+#endif
+  fl_message("Dot plot is now in file\n%s\nin "PDF_OR_PS" format", plotfname);
+#ifndef MICRO
+  matpt->form->show(); Fl::flush();
+#endif
 }
 
 
